# This package is an experiment in active integration of upstream SCM with
# Fedora packaging.  It works something like this:
#
# The "pristine" source is actually a git repo (with no working checkout).
# The first step of %%prep is to check it out and switch to a "fedora" branch.
# If you need to add a patch to the server, just do it like a normal git
# operation, dump it with git-format-patch to a file in the standard naming
# format, and add a PatchN: line.  If you want to push something upstream,
# check out the master branch, pull, cherry-pick, and push.  FIXME describe
# rebasing, add convenience 'make' targets maybe.

%define ansic_major 0
%define ansic_minor 4
%define videodrv_major 10
%define videodrv_minor 0
%define xinput_major 12
%define xinput_minor 2
%define extension_major 5
%define extension_minor 0

%define pkgname xorg-server
#define gitdate 20090903

Summary:   X.Org X11 X server
Name:      xorg-x11-server
Version:   1.10.4
Release:   6%{?dist}
URL:       http://www.x.org
License:   MIT
Group:     User Interface/X
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if 0%{?gitdate}
# git snapshot.  to recreate, run:
# ./make-git-snapshot.sh `cat commitid`
Source0:   xorg-server-%{gitdate}.tar.xz
Source1:   make-git-snapshot.sh
Source2:   commitid
%else
Source0:   http://www.x.org/pub/individual/xserver/%{pkgname}-%{version}.tar.bz2
Source1:   gitignore
%endif

Source10:   xserver.pamd

# "useful" xvfb-run script
Source20:  http://svn.exactcode.de/t2/trunk/package/xorg/xorg-server/xvfb-run.sh

# for requires generation in drivers
Source30: xserver-sdk-abi-requires

Patch6: xserver-1.7.4-z-now.patch

# Trivial things to never merge upstream ever:
# This really could be done prettier.
Patch5002:  xserver-1.4.99-ssh-isnt-local.patch

# don't build the (broken) acpi code
Patch6011: xserver-1.6.0-less-acpi-brokenness.patch

# Make autoconfiguration chose nouveau driver for NVIDIA GPUs
Patch6016: xserver-1.6.1-nouveau.patch

# ajax needs to upstream this
Patch6027: xserver-1.6.0-displayfd.patch
Patch6030: xserver-1.6.99-right-of.patch

# Use vesa for VirtualBox, since we don't ship vboxvideo and the
# fallback to vesa when module is missing seems broken
Patch6053: xserver-1.8-disable-vboxvideo.patch

# misc
Patch7001: xserver-1.10-pointer-barriers.patch
# from ajax/xserver-next
Patch7002: xserver-1.10-bg-none-revert.patch

# 582710 - pam support
Patch7004: xserver-1.1.1-pam.patch
# 585371 - default mode list unification
Patch7006: xserver-1.7.6-default-modes.patch
# 600505 - Xephyr utility should be resizeable
Patch7015: xserver-1.7.7-make-ephyr-resize.patch
# 581505 - Xephyr crashes inside kvm-qemu virtual host
Patch7026: xserver-1.7.7-xephyr-24bpp.patch
# 605302 - vesa doesn't work on intel gen6
Patch7027: xserver-1.7.7-int10-reserved-areas.patch

# upstream backports
Patch7032: xserver-1.10.1-memcpy-abuse.patch
Patch7033: xserver-1.10.1-dri2-fixes.patch

# lame, revert to 1.4.1 ABI for libXfont
Patch7100: xserver-1.10.2-xfont-compat.patch

# Accept -nr command line option for gdm compatibility
Patch7104: xserver-1.10.2-gdm-compat.patch

# Fix randr panning, http://patchwork.freedesktop.org/patch/6488/
Patch7106: xserver-1.10-panning.patch

# 734969 - Server crashes when switching ScreenRecs with PointerKeys (4 patches)
Patch7107: xserver-1.10.4-dix-don-t-allow-keyboard-devices-to-submit-motion-or.patch
Patch7108: xserver-1.10.4-dix-warn-about-keyboard-events-with-valuator-masks.patch
Patch7109: xserver-1.10.4-dix-NewCurrentScreen-must-work-on-pointers-where-pos.patch
Patch7110: xserver-1.10.4-dix-fill-out-root_x-y-for-keyboard-events.patch

# 740581 - Closing/Opening laptop lid in dual head doesn't change screen conf
Patch7111: xserver-1.10.4-lid-hack.patch

Patch7112: xserver-1.10.4-xext-don-t-free-uninitialised-pointer-when-malloc-fa.patch
Patch7113: xserver-1.10.4-Xi-avoid-overrun-of-callback-array.patch
Patch7114: xserver-1.10.4-kinput-allocate-enough-space-for-null-character.patch
Patch7115: xserver-1.10.4-xaa-avoid-possible-freed-pointer-reuse-in-epilogue.patch
Patch7116: xserver-1.10.4-xv-test-correct-number-of-requests.patch
Patch7117: xserver-1.10.4-handle-no-modes-harder.patch

%define moduledir	%{_libdir}/xorg/modules
%define drimoduledir	%{_libdir}/dri
%define sdkdir		%{_includedir}/xorg

%ifarch s390 s390x
%define with_hw_servers 0
%else
%define with_hw_servers 1
%endif

%if %{with_hw_servers}
%define enable_xorg --enable-xorg
%else
%define enable_xorg --disable-xorg
%endif

%define kdrive --enable-kdrive --enable-xephyr --disable-xfake --disable-xfbdev
%define xservers --enable-xvfb --enable-xnest %{kdrive} %{enable_xorg}

BuildRequires: git-core
BuildRequires: automake autoconf libtool pkgconfig
BuildRequires: xorg-x11-util-macros >= 1.1.5

BuildRequires: xorg-x11-proto-devel >= 7.4-27
BuildRequires: xorg-x11-font-utils

BuildRequires: xorg-x11-xtrans-devel >= 1.2.2-1
BuildRequires: libXfont-devel libXau-devel libxkbfile-devel libXres-devel
BuildRequires: libfontenc-devel libXtst-devel libXdmcp-devel
BuildRequires: libX11-devel libXext-devel
BuildRequires: libXinerama-devel libXi-devel

# DMX config utils buildreqs.
BuildRequires: libXt-devel libdmx-devel libXmu-devel libXrender-devel
BuildRequires: libXi-devel libXpm-devel libXaw-devel libXfixes-devel

# Broken, this is global, should be Xephyr-only
BuildRequires: libXv-devel

BuildRequires: pixman-devel >= 0.15.14
BuildRequires: libpciaccess-devel >= 0.10.6-1 openssl-devel byacc flex
BuildRequires: mesa-libGL-devel >= 7.6-0.6
# XXX silly...
BuildRequires: libdrm-devel >= 2.4.0 kernel-headers

BuildRequires: audit-libs-devel libselinux-devel >= 2.0.79-1
BuildRequires: hal-devel dbus-devel
BuildRequires: pam-devel

# All server subpackages have a virtual provide for the name of the server
# they deliver.  The Xorg one is versioned, the others are intentionally
# unversioned.

%description
X.Org X11 X server

%package common
Summary: Xorg server common files
Group: User Interface/X
Requires: pixman >= 0.18.0
Requires: libselinux >= 2.0.79-1
Requires: xkeyboard-config xkbcomp

%description common
Common files shared among all X servers.

%if %{with_hw_servers}
%package Xorg
Summary: Xorg X server
Group: User Interface/X
Provides: Xorg = %{version}-%{release}
Provides: Xserver
Provides: xserver-abi(ansic-%{ansic_major}) = %{ansic_minor}
Provides: xserver-abi(videodrv-%{videodrv_major}) = %{videodrv_minor}
Provides: xserver-abi(xinput-%{xinput_major}) = %{xinput_minor}
Provides: xserver-abi(extension-%{extension_major}) = %{extension_minor}
%ifarch %{ix86} x86_64
Requires: xorg-x11-drv-vesa
%else
Requires: xorg-x11-drv-fbdev
%endif
Requires: xorg-x11-drv-void xorg-x11-drv-evdev >= 2.1.0-3
Requires: xorg-x11-server-common >= %{version}-%{release}
Requires: libdrm >= 2.4.20
Requires: fedora-setup-keyboard
# Dropped from F9 for being broken, uninstall it.
Obsoletes: xorg-x11-drv-magictouch <= 1.0.0.5-5.fc8
# Dropped from F11, use evdev instead
Obsoletes: xorg-x11-drv-calcomp <= 1.1.2-1.fc9
Obsoletes: xorg-x11-drv-citron <= 2.2.1-1.fc9
Obsoletes: xorg-x11-drv-diamondtouch <= 0.2.0-0.1.fc9
Obsoletes: xorg-x11-drv-digitaledge <= 1.1.1-1.fc9
Obsoletes: xorg-x11-drv-dmc <= 1.1.2-1.fc9
Obsoletes: xorg-x11-drv-dynapro <= 1.1.2-1.fc9
Obsoletes: xorg-x11-drv-jamstudio <= 1.2.0-1.fc9
Obsoletes: xorg-x11-drv-magellan <= 1.2.0-1.fc9
Obsoletes: xorg-x11-drv-microtouch <= 1.2.0-1.fc9
Obsoletes: xorg-x11-drv-palmax <= 1.2.0-1.fc9
Obsoletes: xorg-x11-drv-spaceorb <= 1.1.0-6.fc9
Obsoletes: xorg-x11-drv-summa <= 1.2.0-2.fc10
Obsoletes: xorg-x11-drv-tek4957 <= 1.2.0-1.fc9
Obsoletes: xorg-x11-drv-ur98 <= 1.1.0-5.fc9
Obsoletes: xorg-x11-drv-wiimote <= 0.0.1-1.fc9
# Force sufficiently new libpciaccess
Conflicts: libpciaccess < 0.10.6-1
# Force sufficiently new gnome-screensaver
Conflicts: gnome-screensaver < 2.28.3-15

%description Xorg
X.org X11 is an open source implementation of the X Window System.  It
provides the basic low level functionality which full fledged
graphical user interfaces (GUIs) such as GNOME and KDE are designed
upon.
%endif


%package Xnest
Summary: A nested server.
Group: User Interface/X
Obsoletes: xorg-x11-Xnest
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xnest

%description Xnest
Xnest is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.

%package Xdmx
Summary: Distributed Multihead X Server and utilities
Group: User Interface/X
Obsoletes: xorg-x11-Xdmx
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xdmx

%description Xdmx
Xdmx is proxy X server that provides multi-head support for multiple displays
attached to different machines (each of which is running a typical X server).
When Xinerama is used with Xdmx, the multiple displays on multiple machines
are presented to the user as a single unified screen.  A simple application
for Xdmx would be to provide multi-head support using two desktop machines,
each of which has a single display device attached to it.  A complex
application for Xdmx would be to unify a 4 by 4 grid of 1280x1024 displays
(each attached to one of 16 computers) into a unified 5120x4096 display.

%package Xvfb
Summary: A X Windows System virtual framebuffer X server.
Group: User Interface/X
# xvfb-run is GPLv2, rest is MIT
License: MIT and GPLv2
Obsoletes: xorg-x11-Xvfb
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xvfb

%description Xvfb
Xvfb (X Virtual Frame Buffer) is an X server that is able to run on
machines with no display hardware and no physical input devices.
Xvfb simulates a dumb framebuffer using virtual memory.  Xvfb does
not open any devices, but behaves otherwise as an X display.  Xvfb
is normally used for testing servers.


%package Xephyr
Summary: A nested server.
Group: User Interface/X
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xephyr

%description Xephyr
Xephyr is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.  Unlike
Xnest, Xephyr renders to an X image rather than relaying the
X protocol, and therefore supports the newer X extensions like
Render and Composite.


%if %{with_hw_servers}
%package devel
Summary: SDK for X server driver module development
Group: User Interface/X
Obsoletes: xorg-x11-sdk xorg-x11-server-sdk
Requires: xorg-x11-util-macros
Requires: xorg-x11-proto-devel
Requires: pkgconfig pixman-devel libpciaccess-devel
# Virtual provide for transition.  Delete me someday.
Provides: xorg-x11-server-sdk = %{version}-%{release}
# XXX doublecheck me
Provides: libxf86config = %{version}-%{release}
Obsoletes: libxf86config < 1.6.99-29
Provides: libxf86config-devel = %{version}-%{release}
Obsoletes: libxf86config-devel < 1.6.99-29


%description devel
The SDK package provides the developmental files which are necessary for
developing X server driver modules, and for compiling driver modules
outside of the standard X11 source code tree.  Developers writing video
drivers, input drivers, or other X modules should install this package.
%endif

%package source
Summary: Xserver source code required to build VNC server (Xvnc)
Group: Development/Libraries
BuildArch: noarch

%description source
Xserver source code needed to build VNC server (Xvnc)

%prep
%setup -q -n %{pkgname}-%{?gitdate:%{gitdate}}%{!?gitdate:%{version}}

%if 0%{?gitdate}
git checkout -b fedora
sed -i 's/git/&+ssh/' .git/config
if [ -z "$GIT_COMMITTER_NAME" ]; then
    git config user.email "x@fedoraproject.org"
    git config user.name "Fedora X Ninjas"
fi
%else
git init
if [ -z "$GIT_COMMITTER_NAME" ]; then
    git config user.email "x@fedoraproject.org"
    git config user.name "Fedora X Ninjas"
fi
cp %{SOURCE1} .gitignore
git add .
git commit -a -q -m "%{version} baseline."
%endif

# Apply all the patches.
#git am -p1 %{patches}
git am -p1 %{lua: for i, p in ipairs(patches) do print(p.." ") end}

%if %{with_hw_servers}
# check the ABI in the source against what we expect.
getmajor() {
    grep -i ^#define.ABI.$1_VERSION hw/xfree86/common/xf86Module.h |
    tr '(),' '   ' | awk '{ print $4 }'
}

getminor() {
    grep -i ^#define.ABI.$1_VERSION hw/xfree86/common/xf86Module.h |
    tr '(),' '   ' | awk '{ print $5 }'
}

test `getmajor ansic` == %{ansic_major}
test `getminor ansic` == %{ansic_minor}
test `getmajor videodrv` == %{videodrv_major}
test `getminor videodrv` == %{videodrv_minor}
test `getmajor xinput` == %{xinput_major}
test `getminor xinput` == %{xinput_minor}
test `getmajor extension` == %{extension_major}
test `getminor extension` == %{extension_minor}

%endif

%build

%define default_font_path "catalogue:/etc/X11/fontpath.d,built-ins"

%if %{with_hw_servers}
%define dri_flags --with-dri-driver-path=%{drimoduledir}
%else
%define dri_flags --disable-dri
%endif

%if 0%{?rhel}
%define bodhi_flags --with-vendor-web="https://www.redhat.com/apps/support/" --with-vendor-name="Red Hat, Inc."
%endif

# --with-pie ?
./autogen.sh
export CFLAGS="${RPM_OPT_FLAGS} -Wl,-z,relro"
%configure --enable-maintainer-mode %{xservers} \
	--disable-static \
	--with-pic \
	--with-int10=x86emu \
	--with-default-font-path=%{default_font_path} \
	--with-module-dir=%{moduledir} \
	--with-builderstring="Build ID: %{name} %{version}-%{release}" \
	--with-os-name="$(hostname -s) $(uname -r)" \
	--with-xkb-output=%{_localstatedir}/lib/xkb \
	--enable-install-libxf86config \
	--enable-xselinux --enable-record --without-dtrace \
	--enable-config-hal \
	--disable-config-udev \
	%{dri_flags} %{?bodhi_flags} \
	${CONFIGURE}

make V=1 %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT moduledir=%{moduledir}

%if %{with_hw_servers}
rm -f $RPM_BUILD_ROOT%{_libdir}/xorg/modules/libxf8_16bpp.so
rm -rf $RPM_BUILD_ROOT%{_libdir}/xorg/modules/multimedia/
mkdir -p $RPM_BUILD_ROOT%{_libdir}/xorg/modules/{drivers,input}

# yay pam
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -m 0644 %{SOURCE10} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/xserver
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps
touch $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/xserver

mkdir -p $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d

# make sure the (empty) /etc/X11/xorg.conf.d is there, system-setup-keyboard
# relies on it more or less.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/X11/xorg.conf.d

mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -m 755 %{SOURCE30} $RPM_BUILD_ROOT%{_bindir}
%endif

# xdmx (note case) was renamed because hfs+ is case-insentive, lame
ln -s %{_bindir}/dmxinfo $RPM_BUILD_ROOT%{_bindir}/xdmx

# Make the source package
%define xserver_source_dir %{_datadir}/xorg-x11-server-source
%define inst_srcdir %{buildroot}/%{xserver_source_dir}
mkdir -p %{inst_srcdir}/{doc/xml{,/dtrace},Xext,xkb,GL,hw/{xquartz/bundle,xfree86/common}}
mkdir -p %{inst_srcdir}/{hw/dmx/doc,doc/man}
cp {,%{inst_srcdir}/}doc/xml/xmlrules.in
cp {,%{inst_srcdir}/}doc/xml/xmlrules-noinst.in
cp {,%{inst_srcdir}/}doc/xml/xmlrules-inst.in
cp {,%{inst_srcdir}/}doc/xml/xserver.ent.in
cp {,%{inst_srcdir}/}doc/xml/Xserver-spec.xml
cp {,%{inst_srcdir}/}doc/xml/dtrace/Xserver-DTrace.xml
cp {,%{inst_srcdir}/}hw/xquartz/bundle/cpprules.in
cp {,%{inst_srcdir}/}hw/dmx/doc/doxygen.conf.in
cp {,%{inst_srcdir}/}doc/man/Xserver.man
cp {,%{inst_srcdir}/}doc/smartsched
cp xkb/README.compiled %{inst_srcdir}/xkb
cp hw/xfree86/xorgconf.cpp %{inst_srcdir}/hw/xfree86

install -m 0755 %{SOURCE20} $RPM_BUILD_ROOT%{_bindir}/xvfb-run

find . -type f | egrep '.*\.(c|h|am|ac|inc|m4|h.in|pc.in|man.pre|pl|txt)$' |
xargs tar cf - | (cd %{inst_srcdir} && tar xf -)
# SLEDGEHAMMER
find %{inst_srcdir}/hw/xfree86 -name \*.c -delete

# Remove unwanted files/dirs
{
    rm -f $RPM_BUILD_ROOT%{_libdir}/X11/Options
    rm -f $RPM_BUILD_ROOT%{_bindir}/in?
    rm -f $RPM_BUILD_ROOT%{_bindir}/ioport
    rm -f $RPM_BUILD_ROOT%{_bindir}/out?
    rm -f $RPM_BUILD_ROOT%{_bindir}/pcitweak
    rm -f $RPM_BUILD_ROOT%{_mandir}/man1/pcitweak.1*
    find $RPM_BUILD_ROOT -type f -name '*.la' | xargs rm -f -- || :
%if !%{with_hw_servers}
    rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/xorg-server.pc
    rm -f $RPM_BUILD_ROOT%{_datadir}/aclocal/xorg-server.m4
%endif
}

%clean
rm -rf $RPM_BUILD_ROOT


%files common
%defattr(-,root,root,-)
%doc COPYING
%{_mandir}/man1/Xserver.1*
%{_libdir}/xorg/protocol.txt
%dir %{_localstatedir}/lib/xkb
%{_localstatedir}/lib/xkb/README.compiled


%if %{with_hw_servers}
%files Xorg
%defattr(-,root,root,-)
%config %attr(0644,root,root) %{_sysconfdir}/pam.d/xserver
%config(missingok) /etc/security/console.apps/xserver
%{_bindir}/X
%attr(4711, root, root) %{_bindir}/Xorg
%{_bindir}/cvt
%{_bindir}/gtf
%dir %{_libdir}/xorg
%dir %{_libdir}/xorg/modules
%dir %{_libdir}/xorg/modules/drivers
%dir %{_libdir}/xorg/modules/extensions
%{_libdir}/xorg/modules/extensions/libglx.so
%{_libdir}/xorg/modules/extensions/libdri.so
%{_libdir}/xorg/modules/extensions/libdri2.so
%{_libdir}/xorg/modules/extensions/libdbe.so
%{_libdir}/xorg/modules/extensions/libextmod.so
%{_libdir}/xorg/modules/extensions/librecord.so
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/libfbdevhw.so
%{_libdir}/xorg/modules/libexa.so
%{_libdir}/xorg/modules/libfb.so
%{_libdir}/xorg/modules/libint10.so
%{_libdir}/xorg/modules/libshadow.so
%{_libdir}/xorg/modules/libshadowfb.so
%{_libdir}/xorg/modules/libvbe.so
%{_libdir}/xorg/modules/libvgahw.so
%{_libdir}/xorg/modules/libwfb.so
%{_libdir}/xorg/modules/libxaa.so
%{_mandir}/man1/gtf.1*
%{_mandir}/man1/Xorg.1*
%{_mandir}/man1/cvt.1*
%{_mandir}/man4/fbdevhw.4*
%{_mandir}/man4/exa.4*
%{_mandir}/man5/xorg.conf.5*
%{_mandir}/man5/xorg.conf.d.5*
%dir %{_sysconfdir}/X11/xorg.conf.d
%dir %{_datadir}/X11/xorg.conf.d
%endif


%files Xnest
%defattr(-,root,root,-)
%{_bindir}/Xnest
%{_mandir}/man1/Xnest.1*

%files Xdmx
%defattr(-,root,root,-)
%{_bindir}/Xdmx
%{_bindir}/dmxaddinput
%{_bindir}/dmxaddscreen
%{_bindir}/dmxinfo
%{_bindir}/dmxreconfig
%{_bindir}/dmxresize
%{_bindir}/dmxrminput
%{_bindir}/dmxrmscreen
%{_bindir}/dmxtodmx
%{_bindir}/dmxwininfo
%{_bindir}/vdltodmx
%{_bindir}/xdmx
%{_bindir}/xdmxconfig
%{_mandir}/man1/Xdmx.1*
%{_mandir}/man1/dmxtodmx.1*
%{_mandir}/man1/vdltodmx.1*
%{_mandir}/man1/xdmxconfig.1*

%files Xvfb
%defattr(-,root,root,-)
%{_bindir}/Xvfb
%{_bindir}/xvfb-run
%{_mandir}/man1/Xvfb.1*


%files Xephyr
%defattr(-,root,root,-)
%{_bindir}/Xephyr
%{_mandir}/man1/Xephyr.1*


%if %{with_hw_servers}
%files devel
%defattr(-,root,root,-)
%doc COPYING
%{_bindir}/xserver-sdk-abi-requires
%{_libdir}/pkgconfig/xorg-server.pc
%dir %{_includedir}/xorg
%{sdkdir}/*.h
%{_datadir}/aclocal/xorg-server.m4
%{_libdir}/libxf86config.a
%endif


%files source
%defattr(-, root, root, -)
%{xserver_source_dir}

%changelog
* Thu Oct 20 2011 Dave Airlie <airlied@redhat.com> 1.10.4-6
- fix etracer crashes server with no modes (#746926)
- don't allow rightof with single crtc (#738724)

* Thu Oct 20 2011 Dave Airlie <airlied@redhat.com> 1.10.4-5
- coverity fixes (#741558)

* Wed Oct 12 2011 Adam Jackson <ajax@redhat.com> 1.10.4-4
- xserver-1.10.4-lid-hack.patch: Revive. (#740581)
- Conflict against older gnome-screensaver to avoid a deadlock condition
  more easily triggered with the above patch.

* Thu Sep 08 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.4-3
- Fix server crashes when switching ScreenRecs with PointerKeys (#734969)

* Wed Sep 07 2011 Adam Jackson <ajax@redhat.com> 1.10.4-1
- xserver 1.10.4

* Mon Aug 15 2011 Adam Jackson <ajax@redhat.com> 1.10.3-5
- xserver-1.10-panning.patch: Fix RANDR CRTC panning (#655212)

* Mon Jul 25 2011 Adam Jackson <ajax@redhat.com> 1.10.3-4
- Drop multimedia/ in %%install not with %exclude

* Wed Jul 20 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.3-3
- Fix xserver-1.10-2-xfree86-duplicate-xorg.conf-device-information-befor.patch,
  fd must be reset to -1, otherwise drivers may close the log file early.

* Wed Jul 20 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.3-2
- xserver-1.10.3-Initialize-the-fd-to-1-for-xorg.conf-input-devices.patch:
  avoid erroneously closing the log on some drivers (e.g. wacom)

* Thu Jul 14 2011 Adam Jackson <ajax@redhat.com> 1.10.3-1
- xserver-1.7.7-lid-hack.patch: Drop, causes resume failures. (#692776)

* Thu Jul 14 2011 Adam Jackson <ajax@redhat.com> 1.10.3-0.1
- xserver 1.10.3
- xserver-1.10.1-fix-bg-set-crash.patch: Drop, 5752cc47

* Fri Jul 08 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.7
- Fix xserver-1.10-2-xfree86-duplicate-xorg.conf-device-information-befor.patch,
  type_name must be copied and assigned to implicit devices.

* Wed Jul 06 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.6
- xserver-1.10.2-gdm-compat.patch: Fix startup compat with gdm

* Tue Jul 05 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.5
- Three patches to fix input device-related startup crashes.

* Wed Jun 29 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.4
- Enable HAL config backend
- Don't ship the quirks.conf file, this is in 1o-x11-input.fdi

* Tue Jun 28 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.3
- Sync xvfb-run with F15 (#693793)

* Tue Jun 28 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.2
- Add compatibility symlink from xdmx to dmxinfo
- Drop multimedia/, only used by unsupported radeon UMS

* Mon Jun 27 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.1
- Rebase baseline
